pub fn parse_script_code(input: &str) -> Option<ScriptCode>Expand description
Parses a script subtag and normalizes it to title case.
pub fn parse_script_code(input: &str) -> Option<ScriptCode>Parses a script subtag and normalizes it to title case.